;; Generated package description from org-modern.el  -*- no-byte-compile: t -*-
(define-package "org-modern" "0.9" "Modern looks for Org" '((emacs "27.1") (compat "29.1.4.0")) :commit "b614ad31d72c49f9eb29d3836995fd7fb0d1fd4a" :authors '(("Daniel Mendler" . "mail@daniel-mendler.de")) :maintainer '("Daniel Mendler" . "mail@daniel-mendler.de") :url "https://github.com/minad/org-modern")
